def decapitalize(key: str) -> str:
    return key[0].lower() + key[1:]
